gchecky.gxml.Node

Package gchecky :: Module gxml :: Class Node |
[hide private]
[frames] | no frames]

# Class Node

source code

    object --+
             |
            Node

Known Subclasses:
  Document, model.address_filters_t, model.address_t, model.areas_t, model.tax_rule_t, model.alternate_tax_table_t, model.anonymous_address_t, model.buyer_marketing_preferences_t, model.calculate_t, model.carrier_calculated_shipping_adjustment_t, model.carrier_calculated_shipping_option_t, model.carrier_calculated_shipping_t, model.checkout_flow_support_t, model.coupon_gift_adjustment_t, model.default_tax_table_t, model.digital_content_t, model.discount_result_t, model.shipping_option_t, model.item_id_t, model.item_shipping_information_t, model.item_t, model.item_weight_t, model.measure_t, model.merchant_calculations_t, model.merchant_code_results_t, model.merchant_code_string_t, model.merchant_codes_t, model.order_adjustment_t, model.parameterized_url_t, model.pickup_t, model.postal_area_t, model.price_t, model.promotion_t, model.result_t, model.risk_information_t, model.rounding_policy_t, model.ship_from_t, model.shipping_adjustment_t, model.shipping_in_calculate_t, model.shipping_in_order_adjustment_t, model.shipping_methods_t, model.shipping_package_t, model.shopping_cart_t, model.structured_name_t, model.tax_area_t, model.tax_tables_t, model.tracking_data_t, model.url_parameter_t

The base class for any class which represents data that could be mapped into XML DOM structure.

This class provides some basic functionality and lets programmer avoid repetetive tasks by automating it.

See Also: NodeManager

Nested Classes | [hide private]
| __metaclass__ The class keeps track of all the subclasses of `Node` class.

Instance Methods | [hide private]
__init__(self, **kwargs) Directly initialize the instance with values: | source code
write(self, node) Store the Node into an xml DOM node. | source code
read(self, node) Load a Node from an xml DOM node. | source code
__eq__(self, other) | source code
__neq__(self, other) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
set_fields(cls, fields) Method is called by NodeManager to specify this class Fields set. | source code
fields(cls) Return all fields of this class (and its bases) | source code

Static Methods | [hide private]
__new__(cls, **kwargs) Creates a new instance of the class and initializes fields to suitable values. | source code

Class Variables | [hide private]
| _fields = ``{``}`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(cls, **kwargs) Static Method | source code
  Creates a new instance of the class and initializes fields to suitable values. Note that for every meta-`Field` found in the class itself, the instance will have a field initialized to the default value specified in the meta-Field, or one of the Field allowed values, or `None`. Returns:
      a new object with type S, a subtype of T
Overrides: object.__new__

### __init__(self, **kwargs) (Constructor) | source code
Directly initialize the instance with values:
     price = price_t(value = 10, currency = 'USD')
is equivalent to (and preferred over):
     price = price_t()
     price.value = 10
     price.currency = 'USD'
Overrides: object.__init__